@@ -66,7 +66,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 23805530 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 26720857 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -348,7 +348,7 @@ fi
 journalctl=`which journalctl 2> /dev/null | head -n 1`
 
 if [ $? -eq 0 -a -x "$journalctl" ]; then
-    for comm in Xorg Xorg.bin X; do
+    for comm in Xorg Xorg.bin X gdm-x-session; do
         for boot in -0 -1 -2; do
             if journalctl -b $boot -n 1 _COMM=$comm >/dev/null 2>&1; then
                 (
@@ -463,7 +463,7 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
     fi
 ) | $GZIP_CMD >> $LOG_FILENAME
 
-# append Vulkan info
+# append Vulkan ICD info
 
 (
     echo "____________________________________________"
@@ -821,6 +821,25 @@ if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
         echo ""
     )
     
+    # vulkaninfo
+
+    (
+        echo "____________________________________________"
+        echo ""
+
+        vulkaninfo=`which vulkaninfo 2> /dev/null | head -n 1`
+
+        if [ $? -eq 0 -a -x "$vulkaninfo" ]; then
+            echo "$vulkaninfo"
+            echo ""
+            $vulkaninfo 2> /dev/null
+            echo ""
+        else
+            echo "Skipping vulkaninfo output (vulkaninfo not found)"
+            echo ""
+        fi
+    ) | $GZIP_CMD >> $LOG_FILENAME
+
     # nvidia-smi
 
     (
@@ -898,7 +917,7 @@ if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
 
 else
     (
-        echo "Skipping nvidia-smi and nvidia-debugdump due to --safe-mode argument."
+        echo "Skipping nvidia-smi, nvidia-debugdump, and vulkaninfo due to --safe-mode argument."
         echo ""
     ) | $GZIP_CMD >> $LOG_FILENAME
 fi
